@@ -86,5 +86,7 @@ void zonemd_test(void);
 void tcpreuse_test(void);
 /** unit test for doq functions */
 void doq_test(void);
+/** unit test for infra cache functions */
+void infra_test(void);
 
 #endif /* TESTCODE_UNITMAIN_H */
