@@ -41,9 +41,13 @@
  */
 #include "config.h"
 #include "util/rtt.h"
+#include "iterator/iterator.h"
 
 /* overwritten by config: infra_cache_min_rtt: */
 int RTT_MIN_TIMEOUT = 50;
+/* overwritten by config: infra_cache_max_rtt: */
+int RTT_MAX_TIMEOUT = 120000;
+
 /** calculate RTO from rtt information */
 static int
 calc_rto(const struct rtt_info* rtt)
@@ -61,7 +65,7 @@ void
 rtt_init(struct rtt_info* rtt)
 {
 	rtt->srtt = 0;
-	rtt->rttvar = 94;
+	rtt->rttvar = UNKNOWN_SERVER_NICENESS/4;
 	rtt->rto = calc_rto(rtt);
 	/* default value from the book is 0 + 4*0.75 = 3 seconds */
 	/* first RTO is 0 + 4*0.094 = 0.376 seconds */
